# Docker IXagent

This package provides a dockerized IXagent. Note that, depending on the
installation at hand, it might be required to replace the `docker compose`
commands with `docker-compose` (note the replacement of the space with a
hyphen). Newer installations commonly use the space-separated version.

## How to install

To build and start the IXagent, run `docker compose up --build`

## How to use

1. Go to https://portal.ixon.cloud/ to register your free company account.

2. Find your company ID under your account in the top right corner.

3. Run
   `docker compose exec ixagent /usr/bin/ixagent-register.sh <COMPANY_ID>`
   (where <COMPANY_ID> is your company ID)
   to register your device to the IXON platform.

   Alternatively, you may specify the `COMPANY_ID` environmental variable to
   automatically register the IXagent. For example with Docker Compose:

   ```yml
   services:
     ixagent:
       # ...
       environment:
         - COMPANY_ID=0000-0000-0000-0000-0000
       # ...
   ```

4. Go to https://portal.ixon.cloud/ to activate your device and connect
   to it remotely.

To unregister the IXagent, run
`docker compose exec ixagent /usr/bin/ixagent-unregister.sh`

## FAQ

__Q: Why do I require to set NET_ADMIN capabilities in the docker-compose.yml?__

__A:__ The
[NET_ADMIN](https://docs.docker.com/engine/reference/run/#runtime-privilege-and-linux-capabilities)
capability allows tools inside the container to perform various network-related
operations. Because containers are unprivileged by default it can for example
not access devices, change kernel modules or suspend the system. Interactions
with the network stack (like adding TUN/TAP adapters) are restricted as well:
the IXagent however needs to modify these interfaces for VPN to work. Therefore
the NET_ADMIN capability is required when running the container.
