#!/usr/bin/env bash

# Create the TUN character device if it does not exist. This step requires
# `NET_ADMIN` capability, which we cannot trivially obtain at Docker build time.
if [ ! -c /dev/net/tun ]; then
    mkdir -p /dev/net
    mknod /dev/net/tun c 10 200
fi

# Provide the default configuration file if it does not exist.
if [ ! -e /etc/ixon/ixagent.conf ]; then
    cp /etc/ixon/ixagent.orig.conf /etc/ixon/ixagent.conf
fi

# Register the IXagent if the `COMPANY_ID` environmental variable is set.
if [ ! -z "${COMPANY_ID}" ]; then
    {
        # Wait until the IXagent is started.
        ( tail --follow=name --retry --lines=0 /supervisord.log & ) | grep --quiet 'ixagent entered RUNNING state'
        # Register the IXagent.
        /usr/bin/ixagent-register.sh "${COMPANY_ID}"
    } &
fi

# Start supervisord to manage the services.
exec /usr/bin/supervisord --configuration /etc/supervisor/supervisor.conf
