#!/bin/bash

echo "Unregistering this agent may mean you have to reactivate"
echo "This may require paying the activation fee again"
read -p "Continue (y/N)? " choice

case "$choice" in
	y|Y ) ;;
	n|N ) exit 1;;
	* ) exit 1;;
esac

# The following captures the output of the command group.
# Currently this will always wait 2 seconds regardless of if it has any output or not.
# The following "bash magic" happens:
#   We use process substitution twice "<(...)", this creates
#   2 temporary file descriptors which we then concatenate using cat.
#     - The printf file descriptor will simply print whatever is being printed.
#     - The sleep file descriptor won't print anything but cat will still
#       wait for it to complete.
#   We then spawn a background task by piping the output from cat to netcat.
#   Finally we simply wait 2 seconds to kill the background task.
RESULT=$(
	{
		cat <(printf "%s\r\n" "CMD apiclient unregister") <(sleep 2) | nc localhost 9240 &
		pid=$!
		sleep 2
		kill $pid 2> /dev/null
	}
)

if [[ -z "$RESULT" ]]; then
	echo "Agent isn't running"
	exit 1
fi

if [[ ${RESULT} == *"2=Not yet registered"* ]]; then
	echo "Agent isn't registered"
    exit 1
fi

echo "Agent successfully unregistered"
exit 0
